kedro.versioning.journal.Journal — Kedro 0.17.6 documentation

# kedro.versioning.journal.Journal

class `kedro.versioning.journal.` `Journal`(record_data)

  `Journal` class provides journal logging to enable versioning support for Kedro project.

  Methods

  `log_catalog`(dataset_name, operation[, version]) | Log journal record for `DataCatalog`.

  `__init__`(record_data)

    Initialise `Journal` as a session of the journal versioning, and log the project context with an unique identifier.

    Parameters

      record_data (`Dict`[`str`, `Any`]) – JSON serializable dictionary specific to project context.

    Raises

      DeprecationWarning –

  `log_catalog`(dataset_name, operation, version=None)

    Log journal record for `DataCatalog`.

    Parameters

      - dataset_name (`str`) – Name of dataset being logged.

      - operation (`str`) – Operation on dataset, one of {‘save’, ‘load’}.

      - version (`Optional`[`str`]) – Dataset version corresponding to operation (i.e if operation is “save” then this is “save_version”).

    Return type

      `None`